lmi-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[lmi-commits] [lmi] odd/multiarch 392a189 1/5: Import several changes fr


From: Greg Chicares
Subject: [lmi-commits] [lmi] odd/multiarch 392a189 1/5: Import several changes from trunk
Date: Wed, 17 Apr 2019 22:46:20 -0400 (EDT)

branch: odd/multiarch
commit 392a189a378d1ab0e101a450ad0ffde74b74dd2e
Author: Gregory W. Chicares <address@hidden>
Commit: Gregory W. Chicares <address@hidden>

    Import several changes from trunk
---
 install_libxml2_libxslt.make |  6 +++---
 install_msw.sh               | 45 +++++++++++++++++++++++++-------------------
 nychthemeral_test.sh         | 28 +++++++++++++--------------
 3 files changed, 43 insertions(+), 36 deletions(-)

diff --git a/install_libxml2_libxslt.make b/install_libxml2_libxslt.make
index 71d2a91..0e95efb 100644
--- a/install_libxml2_libxslt.make
+++ b/install_libxml2_libxslt.make
@@ -76,7 +76,7 @@ xz_cflags := \
 $(xz_version)_options := \
   --prefix=$(prefix) \
   --exec-prefix=$(exec_prefix) \
-  --build=$(shell $(build_dir)/$(xz_version)/build-aux/config.guess) \
+  --build=`$(build_dir)/$(xz_version)/build-aux/config.guess` \
   --host=$(host_type) \
   --disable-dependency-tracking \
   CFLAGS="-g -O2 $(xz_cflags)" \
@@ -126,7 +126,7 @@ xmlsoft_common_options := \
 $(libxml2_version)_options := \
   --prefix=$(prefix) \
   --exec-prefix=$(exec_prefix) \
-  --build=$(shell $(build_dir)/$(libxml2_version)/config.guess) \
+  --build=`$(build_dir)/$(libxml2_version)/config.guess` \
   --host=$(host_type) \
   $(xmlsoft_common_options) \
   --with-lzma=$(prefix) \
@@ -145,7 +145,7 @@ $(libxml2_version)_options := \
 $(libxslt_version)_options := \
   --prefix=$(prefix) \
   --exec-prefix=$(exec_prefix) \
-  --build=$(shell $(build_dir)/$(libxslt_version)/config.guess) \
+  --build=`$(build_dir)/$(libxslt_version)/config.guess` \
   --host=$(host_type) \
   $(xmlsoft_common_options) \
   --with-libxml-prefix=$(exec_prefix) \
diff --git a/install_msw.sh b/install_msw.sh
index 44e558b..9b74c1c 100755
--- a/install_msw.sh
+++ b/install_msw.sh
@@ -121,30 +121,35 @@ then
     git config --global core.fileMode false
 fi
 
-# Temporary expedient: to test changes to the build system,
-# don't reinstall anything that isn't compiled (to save time),
-# and don't reinstall lmi (so that local modifications to
-# makefiles and scripts aren't overwritten).
-cat >/dev/null <<SUPPRESSED
 java -version
 
+if [ "/opt/lmi/src/lmi" = "$PWD" ]
+then
+    inhibit_git_clone=1
+    print "Running in lmi srcdir, so inhibiting git clone."
+fi
+
 mkdir --parents /opt/lmi/src
 cd /opt/lmi/src || print "Cannot cd"
 
-# Preserve any preexisting source directory, moving it aside so that
-# 'git clone' will install a pristine working copy.
+# Set 'inhibit_git_clone=1' to test uncommitted changes.
+if [ "$inhibit_git_clone" != 1 ]
+then
+    # Preserve any preexisting source directory, moving it aside so
+    # that 'git clone' will install a pristine working copy.
 
-cp --archive lmi lmi-moved-"$stamp0"
-rm -rf /opt/lmi/src/lmi
+    cp --archive lmi lmi-moved-"$stamp0"
+    rm -rf /opt/lmi/src/lmi
 
-# Use git's own protocol wherever possible. In case that's blocked
-# by a corporate firewall, fall back on https. In case a firewall
-# inexplicably blocks the gnu.org domain, try Vadim's github clone
-# as a last resort.
+    # Use git's own protocol wherever possible. In case that's blocked
+    # by a corporate firewall, fall back on https. In case a firewall
+    # inexplicably blocks the gnu.org domain, try Vadim's github clone
+    # as a last resort.
 
-git clone git://git.savannah.nongnu.org/lmi.git \
-  || git clone https://git.savannah.nongnu.org/r/lmi.git \
-  || git clone https://github.com/vadz/lmi.git
+    git clone git://git.savannah.nongnu.org/lmi.git \
+      || git clone https://git.savannah.nongnu.org/r/lmi.git \
+      || git clone https://github.com/vadz/lmi.git
+fi
 
 cd /opt/lmi/src/lmi || print "Cannot cd"
 
@@ -180,7 +185,6 @@ mount
 
 md5sum "$0"
 find /cache_for_lmi/downloads -type f | xargs md5sum
-SUPPRESSED
 
 # Not needed with for-loop below:
 export LMI_HOST=${LMI_HOST:-"i686-w64-mingw32"}
@@ -312,9 +316,12 @@ fi
 # to be discarded, and any differences in the '.git' subdirectory,
 # which are presumably important to keep.
 
-if [ -d /opt/lmi/src/lmi-moved-"$stamp0" ]
+if [ "$inhibit_git_clone" != 1 ]
 then
-cd /opt/lmi/src && mv lmi lmi-new-"$stamp0" && mv lmi-moved-"$stamp0" lmi
+    if [ -d /opt/lmi/src/lmi-moved-"$stamp0" ]
+    then
+    cd /opt/lmi/src && mv lmi lmi-new-"$stamp0" && mv lmi-moved-"$stamp0" lmi
+    fi
 fi
 
 stamp1=$(date -u +'%Y-%m-%dT%H:%M:%SZ')
diff --git a/nychthemeral_test.sh b/nychthemeral_test.sh
index 0878dbd..95227eb 100755
--- a/nychthemeral_test.sh
+++ b/nychthemeral_test.sh
@@ -28,9 +28,9 @@
 # to 'set_arch.sh' can't be right; setting up a symlink can't be
 # any better. Perhaps a subdirectory of 'prefix' should be used
 # instead of 'tmp'? Or should this script instead be...
 #  - called only through a driver that sets "$logdir"?
 #  - refactored as a script function, invoked after setting "$logdir"?
 #  - used preferably as a makefile target that sets "$logdir"?
 #   $make clobber; ./nychthemeral_test.sh 2>&1 | tee 
/tmp/lmi/"$LMI_HOST"/logs/log | sed -f errors.sed
 # Omitting the 'clobber' step when it's known to be unnecessary makes
 # that command take two minutes instead of five on a dual E5-2630 v3
@@ -104,8 +104,8 @@ schemata_clutter='
 '
 
 # Directory for test logs.
-logdir=/tmp/lmi/"$LMI_HOST"/logs
-mkdir --parents "$logdir"
+log_dir=/tmp/lmi/"$LMI_HOST"/logs
+mkdir --parents "$log_dir"
 
 cd /opt/lmi/src/lmi
 
@@ -113,30 +113,30 @@ printf '\n# test concinnity\n\n'
 make "$coefficiency" check_concinnity 2>&1 | sed -e "$build_clutter" -e 
"$concinnity_clutter"
 
 printf '# install; check physical closure\n\n'
-make "$coefficiency" install check_physical_closure 2>&1 | tee 
"$logdir"/install | sed -e "$build_clutter" -e "$install_clutter"
+make "$coefficiency" install check_physical_closure 2>&1 | tee 
"$log_dir"/install | sed -e "$build_clutter" -e "$install_clutter"
 
 printf 'Production system built--ready to start GUI test in another 
session.\n' > /dev/tty
 
 printf '\n# cgi and cli tests\n\n'
-make "$coefficiency" --output-sync=recurse cgi_tests cli_tests 2>&1 | tee 
"$logdir"/cgi-cli | sed -e "$build_clutter" -e "$cli_cgi_clutter"
+make "$coefficiency" --output-sync=recurse cgi_tests cli_tests 2>&1 | tee 
"$log_dir"/cgi-cli | sed -e "$build_clutter" -e "$cli_cgi_clutter"
 
 printf '\n# system test\n\n'
-make "$coefficiency" system_test 2>&1 | tee "$logdir"/system-test | sed -e 
"$build_clutter" -e "$install_clutter"
+make "$coefficiency" system_test 2>&1 | tee "$log_dir"/system-test | sed -e 
"$build_clutter" -e "$install_clutter"
 
 printf '\n# unit tests\n\n'
-make "$coefficiency" unit_tests 2>&1 | tee >(grep '\*\*\*') >(grep \?\?\?\?) 
>(grep '!!!!' --count | xargs printf '%d tests succeeded\n') 
>"$logdir"/unit-tests
+make "$coefficiency" unit_tests 2>&1 | tee >(grep '\*\*\*') >(grep \?\?\?\?) 
>(grep '!!!!' --count | xargs printf '%d tests succeeded\n') 
>"$log_dir"/unit-tests
 
 printf '\n# build with shared-object attributes\n\n'
-make "$coefficiency" all build_type=so_test USE_SO_ATTRIBUTES=1 2>&1 | tee 
"$logdir"/so_test | sed -e "$build_clutter"
+make "$coefficiency" all build_type=so_test USE_SO_ATTRIBUTES=1 2>&1 | tee 
"$log_dir"/so_test | sed -e "$build_clutter"
 
 printf '\n# cgi and cli tests in libstdc++ debug mode\n\n'
-make "$coefficiency" --output-sync=recurse cgi_tests cli_tests 
build_type=safestdlib 2>&1 | tee "$logdir"/cgi-cli-safestdlib | sed -e 
"$build_clutter" -e "$cli_cgi_clutter"
+make "$coefficiency" --output-sync=recurse cgi_tests cli_tests 
build_type=safestdlib 2>&1 | tee "$log_dir"/cgi-cli-safestdlib | sed -e 
"$build_clutter" -e "$cli_cgi_clutter"
 
 printf '\n# unit tests in libstdc++ debug mode\n\n'
-make "$coefficiency" unit_tests build_type=safestdlib 2>&1 | tee >(grep 
'\*\*\*') >(grep \?\?\?\?) >(grep '!!!!' --count | xargs printf '%d tests 
succeeded\n') >"$logdir"/unit-tests-safestdlib
+make "$coefficiency" unit_tests build_type=safestdlib 2>&1 | tee >(grep 
'\*\*\*') >(grep \?\?\?\?) >(grep '!!!!' --count | xargs printf '%d tests 
succeeded\n') >"$log_dir"/unit-tests-safestdlib
 
 printf '\n# xrc tests\n\n'
-java -jar /opt/lmi/third_party/rng/jing.jar -c xrc.rnc *.xrc 2>&1 | tee 
"$logdir"/xrc
+java -jar /opt/lmi/third_party/rng/jing.jar -c xrc.rnc *.xrc 2>&1 | tee 
"$log_dir"/xrc
 
 # Run the following tests in a throwaway directory so that the files
 # they create can be cleaned up easily.
@@ -156,7 +156,7 @@ printf '\n# test all valid emission types\n\n'
 "$PERFORM" /opt/lmi/"$LMI_HOST"/bin/lmi_cli_shared 
--file=/tmp/lmi/tmp/sample.cns --accept --ash_nazg --data_path=/opt/lmi/data 
--emit=emit_test_data,emit_spreadsheet,emit_group_roster,emit_text_stream,emit_custom_0,emit_custom_1
 >/dev/null
 
 printf '\n# schema tests\n\n'
-/opt/lmi/src/lmi/test_schemata.sh 2>&1 | tee "$logdir"/schemata | sed -e 
"$schemata_clutter"
+/opt/lmi/src/lmi/test_schemata.sh 2>&1 | tee "$log_dir"/schemata | sed -e 
"$schemata_clutter"
 
 # Clean up stray output. (The zsh '(N)' glob qualifier turns on
@@ -28,9 +28,9 @@
 # any better. Perhaps a subdirectory of 'prefix' should be used
 # instead of 'tmp'? Or should this script instead be...
-#  - called only through a driver that sets "$logdir"?
-#  - refactored as a script function, invoked after setting "$logdir"?
-#  - used preferably as a makefile target that sets "$logdir"?
+#  - called only through a driver that sets "$log_dir"?
+#  - refactored as a script function, invoked after setting "$log_dir"?
+#  - used preferably as a makefile target that sets "$log_dir"?
 #   $make clobber; ./nychthemeral_test.sh 2>&1 | tee 
/tmp/lmi/"$LMI_HOST"/logs/log | sed -f errors.sed
 # null_glob for a single expansion.)



reply via email to

[Prev in Thread] Current Thread [Next in Thread]